
using System;
using Gtk;

namespace Dizzy
{

	/*
	 * Problema: Supponiamo di avere un thread disperso per il programma
	 * che ad un certo punto decide che deve comunicare all'utente che è
	 * successo un gran casino. Come va? 
	 * 
	 * Soluzione 1: Emette un evento che da qualche altra parte è stato
	 * collegato ad una funzione che crea un dialog. Questo crea problemi
	 * con il fatto che le chiamate alle gtk vengono fatte dal thread sbagliato.
	 * 
	 * Soluzione attuale: Riceviamo le chiamate qua dentro. Questo oggetto
	 * inserisce le chiamate corrette nel thread principale. 
	 */
	
	public class EventManager
	{

		public EventManager () {}
		
		// Metodo generico per segnalare un'errore dell'applicazione.
		public static void ErrorMessage (string message) {
			
			GLib.Idle.Add(delegate {
				Log.Error (message);
				
				MessageDialog d = new Gtk.MessageDialog(null,
				       	                  Gtk.DialogFlags.DestroyWithParent,
				                          Gtk.MessageType.Error,
				                          Gtk.ButtonsType.Ok, "");
				d.Markup = message;
				d.Run ();
				d.Destroy ();
				return false; 
			});
		}
	}
}
